# Credit Card Fraud Example

In this example we will train a Logistic Regression model a credit card fraud dataset, using both `scikit-learn` and `snap-ml-local`. 

The credit card fraud dataset is from the [Kaggle credit card fraud detection competition](https://www.kaggle.com/mlg-ulb/creditcardfraud/data).

## Download the Data

Download and decompress the data from the LIBSVM repository:
```
mkdir data
cd data
```

Download https://www.kaggle.com/mlg-ulb/creditcardfraud/downloads/creditcardfraud.zip into data folder.
```
unzip creditcardfraud.zip
cd ../
```

## Data Pre-processing
The data is in CSV format. We start by performing some pre-processing.

The entire pre-processing can be run by executing `python $CONDA_PREFIX/pai4sk/local-examples/example-creditcard/preprocess-creditcard.py`

Command to pre-process the data available in specific directory:
`python $CONDA_PREFIX/pai4sk/local-examples/example-creditcard/preprocess-creditcard.py --data_path path/to/data` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.


## Training and Evaluating a Logistic Regression Model
One can run the entire example by executing `python $CONDA_PREFIX/pai4sk/local-examples/example-creditcard/example-creditcard.py`

Command to run example using the pre-processed data in specific directory.
`python $CONDA_PREFIX/pai4sk/local-examples/example-creditcard/example-creditcard.py --data_path path/to/data` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.

Command to run example on GPU 0:
python $CONDA_PREFIX/pai4sk/local-examples/example-creditcard/example-creditcard.py --use_gpu

Command to run example on specified GPUs:
python $CONDA_PREFIX/pai4sk/local-examples/example-creditcard/example-creditcard.py --use_gpu --device_ids 1 2

Command to run example with fit_intercept: 
python $CONDA_PREFIX/pai4sk/local-examples/example-creditcard/example-creditcard.py --use_gpu --fit_intercept

Command to collect training information: 
```
python $CONDA_PREFIX/pai4sk/local-examples/example-creditcard/example-creditcard.py --use_gpu --return_training_history=full 

python $CONDA_PREFIX/pai4sk/local-examples/example-creditcard/example-creditcard.py --use_gpu --return_training_history=summary
```
One should see the following output on P9+V100 System (--use_balanced_class_weights --use_gpu --device_ids 0):
```
Data load time (s): 3.60
[pai4sk] Training time (s):  0.38
[pai4sk] Average Precision Score :   0.7327
[pai4sk.lmodel] Training time (s):  0.09
[pai4sk] Average Precision Score :   0.7327
[sklearn] Training time (s):  1.03
[sklearn] Average Precision Score :   0.7327
```

Times will vary depending on the system architecture. 

Note: By default the training will run on CPU. 
With --use_gpu option, default device_ids list contains only GPU 0 for pai4sk and all the available GPUs for pai4sk.lmodel.

&copy; Copyright IBM Corporation 2018, 2019
